#primosalonzo1

Es una tarea de maestría que demuestra que puedo crear un modulo en PYPI y que el crack soy yo German Alonzo
Además que se les manda un saluda todos los primos hermanos alonzos.

Jaja saludos

## Installation

Corre lo siguiente para instalarlo:

'''python
pip install primosalonzo1
'''

## Usage
'''python
from primosalonzo1 import Primos

#Generar n cantidad de primos
Primos(n)